@@ -6,23 +6,25 @@ import sys
 from collections import OrderedDict
 from copy import deepcopy
 from io import IOBase
-from itertools import chain
+from itertools import chain, starmap
 from multiprocessing import Pool
 from subprocess import getstatusoutput
-from traceback import format_exception
 from types import TracebackType
 from typing import (
     Any, Collection, Container, Dict, Iterable, List, Optional, Pattern, Set,
     Tuple, Union
 )
-from warnings import warn
 
 import pkg_resources
 from more_itertools import chunked
 from more_itertools.recipes import grouper
+from packaging.utils import canonicalize_name
 
 from . import find
 
+PACKAGE_VERSION_PATTERN: Pattern = re.compile(
+    r'^\s*([^\s~<>=]*)?\s*([~<>=].*?)?\s*$'
+)
 STRING_LITERAL_RE = (
     # Make sure the quote is not escaped
     r'(?<!\\)('
@@ -43,6 +45,31 @@ INDENT_LENGTH: int = 4
 INDENT: str = " " * INDENT_LENGTH
 
 
+def split_requirement(requirement: str) -> List[str]:
+    """
+    >>> split_requirement('package_name[option-a,option-b]>=1.1,<2.0.1')
+    ['package_name[option-a,option-b]>=1.1', '<2.0.1']
+    """
+    if ']' in requirement:
+        # Package options were specified
+        parts: List[str] = requirement.split(']')
+        package_specifier: str = f"{']'.join(parts[:-1])}]"
+        version_specifiers: List[str] = parts[-1].split(',')
+        return [
+            f'{package_specifier}{version_specifiers[0]}'
+        ] + version_specifiers[1:]
+    else:
+        return requirement.split(',')
+
+
+def get_requirement_package_identifier(requirement: str) -> str:
+    return (
+        PACKAGE_VERSION_PATTERN.match(
+            split_requirement(requirement)[0]
+        ).groups()[0].strip().split('@')[0]
+    )
+
+
 def _get_imbalance(
     text: str,
     boundary_characters: str = '()'
@@ -396,6 +423,12 @@ class SetupScript:
                 pass
         raise KeyError(key)
 
+    def get(self, key: str, default: Any = None) -> Any:
+        try:
+            return self[key]
+        except KeyError:
+            return default
+
     @property
     @functools.lru_cache()
     def _source(self) -> str:
@@ -672,9 +705,7 @@ def _get_source_package_names_versions() -> Dict[str, Any]:
 
 @functools.lru_cache()
 def get_package_version(package_name: str) -> str:
-    normalized_package_name: str = (
-        pkg_resources.Requirement.parse(package_name).name
-    )
+    normalized_package_name: str = canonicalize_name(package_name)
     version: Optional[str] = None
     try:
         version = pkg_resources.get_distribution(
@@ -685,9 +716,7 @@ def get_package_version(package_name: str) -> str:
         # `setup.py`
         for name, version_ in _get_source_package_names_versions().items():
             # If the package name is a match, we will return the version found
-            if name and pkg_resources.Requirement.parse(
-                name
-            ).name == normalized_package_name:
+            if name and canonicalize_name(name) == normalized_package_name:
                 version = version_
                 break
         if version is None:
@@ -709,7 +738,7 @@ def _get_freeze_source_packages(
     for source_package_name, version in (
         _get_source_package_names_versions().items()
     ):
-        source_package_name = source_package_name.replace('_', '-')
+        source_package_name = canonicalize_name(source_package_name)
         package_version = f'{source_package_name}=={version}'
         if source_package_name not in exclude:
             if (not include) or (source_package_name in include):
@@ -718,80 +747,100 @@ def _get_freeze_source_packages(
 
 
 @functools.lru_cache()
-def get_package_requirements(
+def _get_installed_required_package_names(
     package_name: str,
-    recursive: bool = True,
-    _parallelize: bool = True
-) -> List[str]:
-    # Get the output of `pip show`
-    status: int
-    output: str
-    line: str
-    status, output = getstatusoutput(
-        f'{sys.executable} -m pip show {package_name}'
-    )
-    required_package_names: Set[str] = set()
-    package_requirements: List[str] = []
-    for line in output.split('\n'):
-        if line.startswith('Requires:'):
-            requires_package_names: Tuple[str] = tuple(
-                normalized_required_package_name
-                for normalized_required_package_name in (
-                    required_package_name.strip().replace(
-                        '_', '-'
-                    )
-                    for required_package_name in
-                    line[9:].lstrip().split(',')
-                )
-                if normalized_required_package_name
+    parallelize: bool = False,
+    traversed_package_names: Container[str] = ()
+) -> Set[str]:
+    """
+    Get the package name for all of a package's requirements, including extras
+    """
+    package_name = canonicalize_name(package_name)
+    traversed_package_names = set(traversed_package_names) | {package_name}
+    distribution_requires: Iterable[str]
+    required_package_names: Set[str]
+    try:
+        distribution: pkg_resources.Distribution = (
+            pkg_resources.get_distribution(
+                package_name
             )
-            if not requires_package_names:
+        )
+        required_package_names = set(map(
+            lambda required_distribution: required_distribution.name,
+            distribution.requires(
+                extras=tuple(filter(
+                    lambda key: key is not None,
+                    getattr(distribution, '_dep_map', {}).keys()
+                ))
+            )
+        ))
+    except pkg_resources.DistributionNotFound as distribution_not_found_error:
+        setup_script_path: str = ''
+        for entry in pkg_resources.working_set.entries:
+            try:
+                setup_script_path = find.setup_script_path(entry)
+                break
+            except FileNotFoundError:
                 continue
-            required_package_name: str
-            for required_package_name in requires_package_names:
-                if required_package_name not in (
-                    required_package_names
-                ):
-                    package_requirements.append(required_package_name)
-                    required_package_names.add(required_package_name)
-            if recursive:
-                requires_packages_require: Iterable[str]
-                arguments: Iterable[Tuple[str, bool]] = zip(
-                    requires_package_names,
-                    [False] * len(requires_package_names)
+        if not setup_script_path:
+            return set()
+        setup_script: SetupScript = SetupScript(setup_script_path)
+        required_package_names = set()
+        for requirement in (
+            list(setup_script.get('install_requires', [])) +
+            list(setup_script.get('setup_requires', [])) +
+            list(chain(*setup_script.get('extras_require', {}).values()))
+        ):
+            required_package_names.add(
+                canonicalize_name(
+                    get_requirement_package_identifier(
+                        requirement
+                    )
                 )
-                if _parallelize:
-                    pool: Pool
-                    with Pool() as pool:
-                        requires_packages_require = chain(*pool.starmap(
-                            get_package_requirements,
-                            arguments
-                        ))
-                else:
-                    requires_packages_require = chain(*map(
-                        get_package_requirements,
-                        arguments
-                    ))
-                for required_package_name in requires_packages_require:
-                    if required_package_name not in (
-                        required_package_names
-                    ):
-                        package_requirements.append(
-                            required_package_name
-                        )
-                        required_package_names.add(
-                            required_package_name
-                        )
-            break
-    return package_requirements
+            )
+    required_package_names -= traversed_package_names
+    if not required_package_names:
+        return required_package_names
+    traversed_package_names |= required_package_names
+    parallelize_recursive_calls: bool = False
+    if parallelize and len(required_package_names) < 2:
+        parallelize = False
+        parallelize_recursive_calls = True
+    traversed_package_names = tuple(sorted(traversed_package_names))
+    arguments: Iterable[Tuple[str, bool]] = (
+        (
+            required_package_name,
+            parallelize_recursive_calls,
+            traversed_package_names
+        )
+        for required_package_name in
+        required_package_names
+    )
+    parallelize = False
+    if parallelize:
+        pool: Pool
+        with Pool() as pool:
+            required_package_names |= set(chain(*pool.starmap(
+                _get_installed_required_package_names,
+                arguments
+            )))
+    else:
+        required_package_names |= set(chain(*starmap(
+            _get_installed_required_package_names,
+            arguments
+        )))
+    return required_package_names
 
 
 def _flatten_requirements(requirements: Iterable[str]) -> Iterable[str]:
     return chain(*(
         (normalized_package_name,) +
-        tuple(get_package_requirements(normalized_package_name))
+        tuple(_get_installed_required_package_names(
+            normalized_package_name,
+            True
+        ))
         for normalized_package_name in (
-            package_name.replace('_', '-')
+            canonicalize_name(package_name)
             for package_name in (
                 (requirements,)
                 if isinstance(requirements, str) else
@@ -842,15 +891,15 @@ def get_freeze(
         # Get the package name
         if is_editable_requirement:
             if '#egg=' in package_version:
-                package_name = package_version.split('#egg=')[-1].replace(
-                    '_', '-'
+                package_name = canonicalize_name(
+                    package_version.split('#egg=')[-1]
                 )
             else:
                 package_name = package_version[3:]
         if (not editable) and is_editable_requirement:
             package_version = package_name
         if '==' in package_name:
-            package_name = package_name.split('==')[0].replace('_', '-')
+            package_name = canonicalize_name(package_name.split('==')[0])
         elif (not editable) or (not is_editable_requirement):
             package_version = (
                 f'{package_name}=='
@@ -867,4 +916,4 @@ def get_freeze(
                 else:
                     yield package_version
     for package_version in source_package_names.values():
-        yield package_version
+        yield package_version
\ No newline at end of file
